use std::fs;
use std::io::Write;

use anyhow::Result;

use crate::{dirs, Project, Projects};


pub fn clear_selected_project_file() -> Result<()> {
    let cache_file = dirs::selected_project_file();

    if fs::exists(cache_file)? {
        fs::remove_file(cache_file)?;
    }

    Ok(())
}

pub fn write_selected_project_file(project: &Project) -> Result<()> {
    let cache_file = dirs::selected_project_file();
    let path = project.path();

    let mut file = fs::OpenOptions::new()
        .write(true)
        .create(true)
        .truncate(true)
        .open(cache_file)?;
    write!(file, "{}", path.display())?;

    Ok(())
}

pub fn write_projects_file(projects: &Projects) -> Result<()> {
    let projects_file = dirs::data_path().join("projects");

    let file = fs::OpenOptions::new()
        .write(true)
        .create(true)
        .truncate(true)
        .open(projects_file)?;

    bincode::serialize_into(file, projects)?;

    Ok(())
}


pub fn read_projects_file() -> Result<Projects> {
    let projects_file = dirs::data_path().join("projects");

    if !projects_file.exists() {
        return Ok(Projects::default());
    }

    let file = std::fs::File::open(projects_file)?;
    let projects = bincode::deserialize_from(file)?;

    Ok(projects)
}
